summaryrefslogtreecommitdiff
path: root/gtk2_ardour/midi_region_view.h
diff options
context:
space:
mode:
authorPaul Davis <paul@linuxaudiosystems.com>2009-09-08 21:45:44 +0000
committerPaul Davis <paul@linuxaudiosystems.com>2009-09-08 21:45:44 +0000
commit1bf79fa88502a156a71cd3d2de35aa234950c40c (patch)
treed17b2e9ed485511ac557647c4b331054c1d477c0 /gtk2_ardour/midi_region_view.h
parent539c8361de35364effe804e2db184790226b340a (diff)
move note drag & note resize mouse handling up into the Drag/Editor infrastructure/level
git-svn-id: svn://localhost/ardour2/branches/3.0@5641 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/midi_region_view.h')
-rw-r--r--gtk2_ardour/midi_region_view.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/gtk2_ardour/midi_region_view.h b/gtk2_ardour/midi_region_view.h
index 5a7955e140..08dea544e2 100644
--- a/gtk2_ardour/midi_region_view.h
+++ b/gtk2_ardour/midi_region_view.h
@@ -201,24 +201,24 @@ class MidiRegionView : public RegionView
/** Begin resizing of some notes.
* Called by CanvasMidiNote when resizing starts.
* @param note_end which end of the note, NOTE_ON or NOTE_OFF
*/
- void begin_resizing(ArdourCanvas::CanvasNote::NoteEnd note_end);
+ void begin_resizing(bool at_front);
/** Update resizing notes while user drags.
* @param note_end which end of the note, NOTE_ON or NOTE_OFF
* @param x the difference in mouse motion, ie the motion difference if relative=true
* or the absolute mouse position (track-relative) if relative is false
* @param relative true if relative resizing is taking place, false if absolute resizing
*/
- void update_resizing(ArdourCanvas::CanvasNote::NoteEnd note_end, double x, bool relative);
+ void update_resizing(bool at_front, double x, bool relative);
/** Finish resizing notes when the user releases the mouse button.
* @param note_end which end of the note, NOTE_ON or NOTE_OFF
* @param event_x the absolute mouse position (track-relative)
* @param relative true if relative resizing is taking place, false if absolute resizing
*/
- void commit_resizing(ArdourCanvas::CanvasNote::NoteEnd note_end, double event_x, bool relative);
+ void commit_resizing(bool at_front, double event_x, bool relative);
/** Adjust the velocity on a note, and the selection if applicable.
* @param velocity the relative or absolute velocity
@@ -244,7 +244,6 @@ class MidiRegionView : public RegionView
struct NoteResizeData {
ArdourCanvas::CanvasNote *canvas_note;
ArdourCanvas::SimpleRect *resize_rect;
- double current_x;
};
/** Snap a region relative pixel coordinate to pixel units.
@@ -201,24 +201,24 @@ class MidiRegionView : public RegionView
/** Begin resizing of some notes.
* Called by CanvasMidiNote when resizing starts.
- * @param note_end which end of the note, NOTE_ON or NOTE_OFF
+ * @param at_front which end of the note (true == note on, false == note off)
*/
@@ -201,24 +201,24 @@ class MidiRegionView : public RegionView
/** Update resizing notes while user drags.
- * @param note_end which end of the note, NOTE_ON or NOTE_OFF
+ * @param at_front which end of the note (true == note on, false == note off)
* @param x the difference in mouse motion, ie the motion difference if relative=true
* or the absolute mouse position (track-relative) if relative is false
@@ -201,24 +201,24 @@ class MidiRegionView : public RegionView
/** Finish resizing notes when the user releases the mouse button.
- * @param note_end which end of the note, NOTE_ON or NOTE_OFF
+ * @param at_front which end of the note (true == note on, false == note off)
* @param event_x the absolute mouse position (track-relative)
* @param relative true if relative resizing is taking place, false if absolute resizing